<div ng-switch="params.reporttype">
	<div ng-switch-when="hosts" class="dataTitle">
		Host {{params.host}}
	</div>
	<div ng-switch-when="services" class="dataTitle">
		Service {{params.service}} on  {{params.host}}
	</div>
	<div ng-switch-default class="dataTitle">
		Histogram
	</div>
</div>
<br/>
<img ng-src="{{params.cgiurl}}../images/trends.gif" border="0"
		alt="Host Event Histogram" title="Host Event Histogram"
		ng-show="params.reporttype == 'hosts'">
<img ng-src="{{params.cgiurl}}../images/trends.gif" border="0"
		alt="Service Event Histogram" title="Service Event Histogram"
		ng-show="params.reporttype == 'services'">
<br clear="all"/>
<div class="reportRange">
	{{params.t1 * 1000 | date:'MM-dd-yy HH:mm:ss'}} to
	{{params.t2 * 1000 | date:'MM-dd-yy HH:mm:ss'}}
</div>
<div class="reportDuration">
	Duration: {{(params.t2 - params.t1) * 1000 | duration}}
</div>
