<table class="infoBox" border="1" cellspacing="0" cellpadding="0">
	<tbody>
		<tr>
			<td class="infoBox">
				<button type="button" class="btn btn-xs btn-default btn-noshadow"
						ng-click="toggleDisplay()" ng-if="isCollapsable">
					<span ng-hide="isPermanentlyCollapsed">&#x2227;</span>
					<span ng-show="isPermanentlyCollapsed">&#x2228;</span>
				</button>
				<span class="infoBoxTitle">
					{{decorationTitle}}
				</span>
				<div ng-hide="isCollapsed">
					Last Updated: {{lastUpdate | date:'EEE MMM dd HH:mm:ss yyyy'}}
					<br>
					Nagios&reg; Core&trade; {{json.data.programstatus.version}} -
					<a href="https://www.nagios.org" target="_new"
							class="homepageURL">www.nagios.org</a>
					<br>
					<span ng-show="updateInterval > 0">
						Updated every {{updateInterval}} seconds
						<br/>
					</span>
					<span ng-show="haveProgramStatus">
						Logged in as <i>{{json.result.user}}</i>
						<br>
					</span>
					<div class="infoBoxBadProcStatus"
							ng-hide="haveProgramStatus">
						Warning: Monitoring process may not be running!
						<br/>
						Click <a href="{{cgiurl}}extinfo.cgi?type=0">here</a>
						for more info.
					</div>
					<!--div class="infoBoxBadProcStatus">
						Warning: Could not read program status information!
					</div-->
					<div class="infoBoxBadProcStatus"
							ng-show="notificationsDisabled()">
						- Notifications are disabled
					</div>
					<div class="infoBoxBadProcStatus"
							ng-show="serviceChecksDisabled()">
						- Service checks are disabled
					</div>
				</div>
			</td>
		</tr>
	</tbody>
</table>
<div ng-hide="isCollapsed" ng-include="includePartial"></div>
