/* Styles for the body as whole */
body {
	margin: 0;
}

/* Styles for the map header div */
div#header-container {
	position: absolute;
	top: 1px;
	left: 1px;
	width: 320px;
	z-index: 30;
}

/* Container for the map svg */
div#map-container {
	position: absolute;
	width: 100%;
	height: 100%;
}

/* Class to remove shadow from bootstrap buttons */
.btn-noshadow:focus,
.btn-noshadow:active {
	outline: none;
	-webkit-box-shadow: none !important;
	-moz-box-shadow: none !important;
	box-shadow: none !important;
}
